@@ -3,20 +3,17 @@ package Number::Phone::JP::Table::Class2;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.20100104';
 
-# Table last modified: 2008-06-04
+# Table last modified: 2010-01-04
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '09120'  => '\d+', # ブラステル
     '09121'  => '\d+', # ブラステル
     '09130'  => '\d+', # ドコモ
-    '09144'  => '\d+', # アルフゼネットワーク
-    '09145'  => '\d+', # アルフゼネットワーク
     '09155'  => '\d+', # NTT-ME
     '09156'  => '\d+', # NTT-ME
     '09177'  => '\d+', # ソフトバンクBB
-    '09180'  => '\d+', # スピーディア
     '09181'  => '\d+', # 関西コムネット
     '09191'  => '\d+', # NTTぷらら
     '09192'  => '\d+', # NTTぷらら
